@@ -1,4 +1,10 @@
 package MooseX::Workers::Engine;
+BEGIN {
+  $MooseX::Workers::Engine::AUTHORITY = 'cpan:PERIGRIN';
+}
+{
+  $MooseX::Workers::Engine::VERSION = '0.17';
+}
 use Moose;
 use POE qw(Wheel::Run);
 
@@ -121,6 +127,16 @@ sub kill_worker {
     $self->remove_worker($wheel_id);
 }
 
+sub stdout_filter {
+	my $self = $_[OBJECT];
+	$self->visitor->stdout_filter;
+}
+
+sub stderr_filter {
+	my $self = $_[OBJECT];
+	$self->visitor->stderr_filter;
+}
+
 #
 # EVENTS
 #
@@ -148,10 +164,16 @@ sub add_worker {
         $command = $job;
     }
 
+	my @optional_io_filters;
+	push @optional_io_filters, 'StdoutFilter', $self->stdout_filter   if $self->stdout_filter;
+	push @optional_io_filters, 'StderrFilter', $self->stderr_filter   if $self->stderr_filter;
+	
     $args = [$args] unless ref $args eq 'ARRAY';
+
     my $wheel = POE::Wheel::Run->new(
         Program     => $command,
         ProgramArgs => $args,
+		@optional_io_filters,
         StdoutEvent => '_worker_stdout',
         StderrEvent => '_worker_stderr',
         ErrorEvent  => '_worker_error',
@@ -166,7 +188,7 @@ sub add_worker {
        $job->PID($wheel->PID);
        $self->set_job( $wheel->ID => $job );
        if ($job->timeout) {
-          $$heap{wheel_to_timer}{$wheel->ID} =
+          $heap->{wheel_to_timer}{$wheel->ID} =
              $kernel->delay_set('_kill_worker', $job->timeout, $wheel->ID);
        }
     } 
@@ -251,7 +273,7 @@ sub _worker_error {
 sub _worker_done {
     my ($self, $wheel_id, $kernel, $heap) = @_[ OBJECT, ARG0, KERNEL, HEAP ];
     my $job = $self->get_job($wheel_id);
-    $kernel->alarm_remove(delete $$heap{wheel_to_timer}{$wheel_id});
+    $kernel->alarm_remove(delete $heap->{wheel_to_timer}{$wheel_id}) if $heap->{wheel_to_timer}{$wheel_id};
     if ($self->visitor->can('worker_done')) {
         if ($job) {
             $self->visitor->worker_done( $job );
@@ -261,6 +283,10 @@ sub _worker_done {
     }
     $self->delete_worker( $wheel_id );
 
+    if (my $code = $self->visitor->can('worker_finished')) {
+        $self->visitor->$code($job ? $job : ());
+    }
+
     # If we have free workers and processes in queue, then dequeue one of them.
     while ( $self->num_workers < $self->max_workers && 
             (my $jobref = $self->dequeue_process)
@@ -336,7 +362,7 @@ Hold a reference to our main object so we can use the callbacks on it.
 
 =item max_workers
 
-An Integer specifying the maxium number of workers we have.
+An Integer specifying the maximum number of workers we have.
 
 =item workers
 
